pub struct AutoChestGatings {
pub autochest_button_unlock_chapter: i64,
pub rarity_filter_unlock: i64,
pub guaranteed_stat_unlock: i64,
pub first_additional_stat_unlock: i64,
pub second_additional_stat_unlock: i64,
pub third_additional_stat_unlock: i64,
}Fields
rarity_filter_unlock: i64guaranteed_stat_unlock: i64first_additional_stat_unlock: i64second_additional_stat_unlock: i64third_additional_stat_unlock: i64Trait Implementations
Sourceimpl Clone for AutoChestGatings
impl Clone for AutoChestGatings
Sourcefn clone(&self) -> AutoChestGatings
fn clone(&self) -> AutoChestGatings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutoChestGatings
impl Debug for AutoChestGatings
Sourceimpl Default for AutoChestGatings
impl Default for AutoChestGatings
Sourcefn default() -> AutoChestGatings
fn default() -> AutoChestGatings
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AutoChestGatings
impl<'de> Deserialize<'de> for AutoChestGatings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AutoChestGatings
impl JsonSchema for AutoChestGatings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AutoChestGatings
impl PartialEq for AutoChestGatings
Sourceimpl Serialize for AutoChestGatings
impl Serialize for AutoChestGatings
Sourceimpl Tsify for AutoChestGatings
impl Tsify for AutoChestGatings
const DECL: &'static str = "export interface AutoChestGatings {\n autochest_button_unlock_chapter: number;\n rarity_filter_unlock: number;\n guaranteed_stat_unlock: number;\n first_additional_stat_unlock: number;\n second_additional_stat_unlock: number;\n third_additional_stat_unlock: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for AutoChestGatings
impl StructuralPartialEq for AutoChestGatings