pub struct CastleGating {
pub castle_button_unlock_chapter: i64,
pub talent_tree_unlock_chapter: i64,
pub statue_unlock_chapter: i64,
}Fields
talent_tree_unlock_chapter: i64statue_unlock_chapter: i64Trait Implementations
Sourceimpl Clone for CastleGating
impl Clone for CastleGating
Sourcefn clone(&self) -> CastleGating
fn clone(&self) -> CastleGating
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CastleGating
impl Debug for CastleGating
Sourceimpl Default for CastleGating
impl Default for CastleGating
Sourcefn default() -> CastleGating
fn default() -> CastleGating
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CastleGating
impl<'de> Deserialize<'de> for CastleGating
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CastleGating
impl JsonSchema for CastleGating
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CastleGating
impl PartialEq for CastleGating
Sourceimpl Serialize for CastleGating
impl Serialize for CastleGating
Sourceimpl Tsify for CastleGating
impl Tsify for CastleGating
const DECL: &'static str = "export interface CastleGating {\n castle_button_unlock_chapter: number;\n talent_tree_unlock_chapter: number;\n statue_unlock_chapter: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for CastleGating
impl StructuralPartialEq for CastleGating