pub struct Gatings {
pub navbar_navigation: NavBarNavigation,
pub sidebar_navigation: SideBarNavigation,
pub autochest: AutoChestGatings,
pub afk_rewards_button_unlock_chapter: i64,
pub party_unlock_chapter: i64,
}Fields
autochest: AutoChestGatingsparty_unlock_chapter: i64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Gatings
impl<'de> Deserialize<'de> for Gatings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Gatings
impl JsonSchema for Gatings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for Gatings
impl Tsify for Gatings
const DECL: &'static str = "export interface Gatings {\n navbar_navigation: NavBarNavigation;\n sidebar_navigation: SideBarNavigation;\n autochest: AutoChestGatings;\n afk_rewards_button_unlock_chapter: number;\n party_unlock_chapter: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Gatings
impl StructuralPartialEq for Gatings