pub struct NavBarNavigation {
pub hero_button_unlock_chapter: i64,
pub skills_button_unlock_chapter: i64,
pub dungeon_button_unlock_chapter: i64,
pub summon_button_unlock_chapter: i64,
pub pets_button_unlock_chapter: i64,
pub castle: CastleGating,
}Fields
castle: CastleGatingTrait Implementations
Sourcefn clone(&self) -> NavBarNavigation
fn clone(&self) -> NavBarNavigation
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourcefn default() -> NavBarNavigation
fn default() -> NavBarNavigation
Returns the “default value” for a type. Read more
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreconst DECL: &'static str = "export interface NavBarNavigation {\n hero_button_unlock_chapter: number;\n skills_button_unlock_chapter: number;\n dungeon_button_unlock_chapter: number;\n summon_button_unlock_chapter: number;\n pets_button_unlock_chapter: number;\n castle: CastleGating;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>